package com.chuanglan.shanyan_sdk_test_demo.view;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;

import com.chuanglan.shanyan_sdk.OneKeyLoginManager;
import com.chuanglan.shanyan_sdk.listener.OnClickPrivacyListener;
import com.chuanglan.shanyan_sdk.listener.OneKeyLoginListener;
import com.chuanglan.shanyan_sdk.listener.OpenLoginAuthListener;
import com.chuanglan.shanyan_sdk_test_demo.R;
import com.chuanglan.shanyan_sdk_test_demo.utils.AbScreenUtils;
import com.chuanglan.shanyan_sdk_test_demo.utils.ConfigUtils;


public class HomeActivity extends BaseActivity implements View.OnClickListener {
    private LinearLayout home_land_model;
    private LinearLayout home_dialog_model;
    private LinearLayout home_debug_model;
    private LinearLayout home_port_model;
    private long startTime;
    private RelativeLayout loading_view;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_home);
        initViews();
        setListener();
    }

    private void setListener() {
        //闪验SDK 协议栏 点击协议监听（开发者无此需求可不加）
        OneKeyLoginManager.getInstance().setOnClickPrivacyListener(new OnClickPrivacyListener() {

            @Override
            public void getOnClickPrivacyStatus(int code, String result, String operator) {
                AbScreenUtils.showToast(getApplicationContext(), "result=" + result + "operator=" + operator);
            }
        });

        home_land_model.setOnClickListener(this);
        home_dialog_model.setOnClickListener(this);
        home_debug_model.setOnClickListener(this);
        home_port_model.setOnClickListener(this);
    }


    private void initViews() {
        home_land_model = findViewById(R.id.home_land_model);
        home_dialog_model = findViewById(R.id.home_dialog_model);
        home_debug_model = findViewById(R.id.home_debug_model);
        home_port_model = findViewById(R.id.home_port_model);
        loading_view = findViewById(R.id.my_dialog_layout);
    }


    private void openLoginActivity() {
        //开始拉取授权页
        OneKeyLoginManager.getInstance().openLoginAuth(false, new OpenLoginAuthListener() {
            @Override
            public void getOpenLoginAuthStatus(int code, String result) {
                if (null != loading_view) {
                    loading_view.setVisibility(View.GONE);
                }
                if (1000 == code) {
                    Log.e("VVV", "拉起授权页成功： code==" + code + "   result==" + result);
                } else {
                    Log.e("VVV", "拉起授权页失败： code==" + code + "   result==" + result);
                    AbScreenUtils.showToast(getApplicationContext(), result);
                }
            }
        }, new OneKeyLoginListener() {
            @Override
            public void getOneKeyLoginStatus(int code, String result) {
                if (null != loading_view) {
                    loading_view.setVisibility(View.GONE);
                }
                if (1011 == code) {
                    Log.e("VVV", "用户点击授权页返回： code==" + code + "   result==" + result);
                    return;
                } else if (1000 == code) {
                    Log.e("VVV", "用户点击登录获取token成功： code==" + code + "   result==" + result);
                } else {
                    Log.e("VVV", "用户点击登录获取token失败： code==" + code + "   result==" + result);
                }
                startTime = System.currentTimeMillis();
                startResultActivity(code, result);
            }
        });
    }

    private void startResultActivity(int code, String result) {
        Intent intent = new Intent(HomeActivity.this, ResultActivity.class);
        intent.putExtra("startTime", startTime);
        intent.putExtra("loginResult", result);
        intent.putExtra("loginCode", code);
        startActivity(intent);
        OneKeyLoginManager.getInstance().finishAuthActivity();
    }


    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            //横屏模式
            case R.id.home_land_model:
                Intent intentLand = new Intent(HomeActivity.this, LandscapeActivity.class);
                startActivity(intentLand);
                break;
            //弹框模式
            case R.id.home_dialog_model:
                loading_view.setVisibility(View.VISIBLE);
                OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getDialogUiConfig(getApplicationContext()));
                openLoginActivity();
                break;
            //竖屏模式
            case R.id.home_port_model:
                loading_view.setVisibility(View.VISIBLE);
                OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getCJSConfig(getApplicationContext()));
                openLoginActivity();
                break;
            //调试模式
            case R.id.home_debug_model:
                Intent intent = new Intent(HomeActivity.this, DebugModeActivity.class);
                startActivity(intent);
                break;

        }
    }


    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (loading_view != null) {
            loading_view.setVisibility(View.GONE);
        }
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (loading_view != null) {
            loading_view.setVisibility(View.GONE);
        }
    }

}
